package com.inspect.patrol.mapper;

import com.inspect.patrol.domain.PatrolPresetRecord;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface PatrolPresetRecordMapper {
    PatrolPresetRecord selectPatrolPresetRecordByPresetRecordId(Long recordId);

    List<PatrolPresetRecord> selectPatrolPresetRecordList(PatrolPresetRecord record);

    int insertPatrolPresetRecord(PatrolPresetRecord record);

    int updatePatrolPresetRecord(PatrolPresetRecord record);

    int deletePatrolPresetRecordByPresetRecordId(Long recordId);

    int deletePatrolPresetRecordByPresetRecordIds(Long[] recordIds);
}
